#ifndef SERVER_H_
#define SERVER_H_

extern void ResetCallBack();
extern void ResetAfterCallBack();

extern void Debug_data_init(void);

extern void StartupPasswdGuiCheck();
extern void Service_Gui(void);

extern void Service_Time_1mS(void);
extern void Service_Time_10mS(void);
extern void Service_Time_100mS(void);

extern void Service_Init(void);
extern void Service(void);

extern void PreventPermissionDown();

extern void ProcessUserSetAutoState();
extern void ProcessUserSetManualState();

extern void HotKeyResetCallBack();
extern void HotKeyAlramCallBack();
extern void HotKeySelfCheckCallBack();

extern void KeepInUiJustEnter();
extern void KeepInUiOperating();

extern void SysDoRecover();











#endif
